// Machine generated IDispatch wrapper class(es) created with ClassWizard
/////////////////////////////////////////////////////////////////////////////
// ISoundEditor wrapper class

class ISoundEditor : public COleDispatchDriver
{
public:
	ISoundEditor() {}		// Calls COleDispatchDriver default constructor
	ISoundEditor(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	ISoundEditor(const ISoundEditor& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	LPDISPATCH GetEventGroups();
	void SetEventGroups(LPDISPATCH);
	long GetVersionNumber();
	void SetVersionNumber(long);

// Operations
public:
	BOOL OpenDocument(LPCTSTR csFilename);
	BOOL SaveDocument(LPCTSTR csFilename);
	BOOL AddSoundDirectory(LPCTSTR csPath);
	BOOL RebuildBanks();
	BOOL SaveLocalizedBanks(LPCTSTR _csDocumentPath, LPCTSTR _csLanguage);
	LPDISPATCH FindResFromEditorId(long _iId);
	BOOL SetSoundDriver(BOOL bSet);
	BOOL UnloadAllEvents();
	long GetPosSound(long Handle);
	BOOL SetDriverActivation(BOOL bActivate);
};
/////////////////////////////////////////////////////////////////////////////
// IEventGroup wrapper class

class IEventGroup : public COleDispatchDriver
{
public:
	IEventGroup() {}		// Calls COleDispatchDriver default constructor
	IEventGroup(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IEventGroup(const IEventGroup& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	long GetId();
	void SetId(long);
	CString GetName();
	void SetName(LPCTSTR);
	LPDISPATCH GetResources();
	void SetResources(LPDISPATCH);
	LPDISPATCH GetEvents();
	void SetEvents(LPDISPATCH);
	CString GetFilePath();
	void SetFilePath(LPCTSTR);
	long GetVersionNumber();
	void SetVersionNumber(long);

// Operations
public:
	BOOL RemoveAll();
	BOOL CompactIds();
};
/////////////////////////////////////////////////////////////////////////////
// ISND_EdiBank wrapper class

class ISND_EdiBank : public COleDispatchDriver
{
public:
	ISND_EdiBank() {}		// Calls COleDispatchDriver default constructor
	ISND_EdiBank(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	ISND_EdiBank(const ISND_EdiBank& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
};
/////////////////////////////////////////////////////////////////////////////
// ISND_EdiMap wrapper class

class ISND_EdiMap : public COleDispatchDriver
{
public:
	ISND_EdiMap() {}		// Calls COleDispatchDriver default constructor
	ISND_EdiMap(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	ISND_EdiMap(const ISND_EdiMap& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
};
/////////////////////////////////////////////////////////////////////////////
// IEventGroups wrapper class

class IEventGroups : public COleDispatchDriver
{
public:
	IEventGroups() {}		// Calls COleDispatchDriver default constructor
	IEventGroups(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IEventGroups(const IEventGroups& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	long GetCount();
	void SetCount(long);

// Operations
public:
	LPDISPATCH Item(long Index);
	LPDISPATCH FindItem(LPCTSTR csName);
	LPDISPATCH Add(LPCTSTR csName);
	BOOL Remove(LPCTSTR csEventGroupName);
	LPUNKNOWN Get_NewEnum();
};
/////////////////////////////////////////////////////////////////////////////
// IResource wrapper class

class IResource : public COleDispatchDriver
{
public:
	IResource() {}		// Calls COleDispatchDriver default constructor
	IResource(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IResource(const IResource& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetName();
	void SetName(LPCTSTR);
	long GetVolume();
	void SetVolume(long);
	LPDISPATCH GetSampleRes();
	void SetSampleRes(LPDISPATCH);
	long GetType();
	void SetType(long);
	long GetDataOffset();
	void SetDataOffset(long);
	long GetDataSize();
	void SetDataSize(long);
	long GetId();
	void SetId(long);

// Operations
public:
};
/////////////////////////////////////////////////////////////////////////////
// IResources wrapper class

class IResources : public COleDispatchDriver
{
public:
	IResources() {}		// Calls COleDispatchDriver default constructor
	IResources(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IResources(const IResources& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	long GetCount();
	void SetCount(long);

// Operations
public:
	LPDISPATCH Item(long Index);
	LPDISPATCH FindItem(LPCTSTR csName);
	LPDISPATCH Add(LPCTSTR csName);
	LPDISPATCH AddSampleRes(LPCTSTR csName);
	BOOL Remove(LPCTSTR csResName);
	LPUNKNOWN Get_NewEnum();
};
/////////////////////////////////////////////////////////////////////////////
// ISampleResource wrapper class

class ISampleResource : public COleDispatchDriver
{
public:
	ISampleResource() {}		// Calls COleDispatchDriver default constructor
	ISampleResource(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	ISampleResource(const ISampleResource& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	CString GetFileName();
	void SetFileName(LPCTSTR);
	long GetZipType();
	void SetZipType(long);
	BOOL GetLoop();
	void SetLoop(BOOL);
	long GetStartLoop();
	void SetStartLoop(long);
	long GetLoopLength();
	void SetLoopLength(long);

// Operations
public:
	BOOL SetSampleData(LPCTSTR csFilename);
	LPDISPATCH GetResource();
};
/////////////////////////////////////////////////////////////////////////////
// IEvents wrapper class

class IEvents : public COleDispatchDriver
{
public:
	IEvents() {}		// Calls COleDispatchDriver default constructor
	IEvents(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IEvents(const IEvents& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	long GetCount();
	void SetCount(long);

// Operations
public:
	LPDISPATCH Item(long Index);
	LPDISPATCH FindItem(LPCTSTR csName);
	LPDISPATCH Add(LPCTSTR csName);
	LPDISPATCH AddPlayEvent(LPDISPATCH Resource);
	LPDISPATCH AddStopEvent(LPDISPATCH lpEvent);
	BOOL Remove(LPCTSTR csEventName);
	LPUNKNOWN Get_NewEnum();
};
/////////////////////////////////////////////////////////////////////////////
// IEvent wrapper class

class IEvent : public COleDispatchDriver
{
public:
	IEvent() {}		// Calls COleDispatchDriver default constructor
	IEvent(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IEvent(const IEvent& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:
	long GetId();
	void SetId(long);
	CString GetName();
	void SetName(LPCTSTR);
	BOOL GetDynamic();
	void SetDynamic(BOOL);
	BOOL GetStopable();
	void SetStopable(BOOL);
	long GetType();
	void SetType(long);

// Operations
public:
	LPDISPATCH GetResource();
	BOOL LoadData();
	BOOL UnloadData();
	long Play();
	BOOL LoadPlayUnload();
};
/////////////////////////////////////////////////////////////////////////////
// IOptionsSheet wrapper class

class IOptionsSheet : public COleDispatchDriver
{
public:
	IOptionsSheet() {}		// Calls COleDispatchDriver default constructor
	IOptionsSheet(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IOptionsSheet(const IOptionsSheet& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
};
/////////////////////////////////////////////////////////////////////////////
// IEventOptionsPage wrapper class

class IEventOptionsPage : public COleDispatchDriver
{
public:
	IEventOptionsPage() {}		// Calls COleDispatchDriver default constructor
	IEventOptionsPage(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IEventOptionsPage(const IEventOptionsPage& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
};
/////////////////////////////////////////////////////////////////////////////
// IResOptionsPage wrapper class

class IResOptionsPage : public COleDispatchDriver
{
public:
	IResOptionsPage() {}		// Calls COleDispatchDriver default constructor
	IResOptionsPage(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IResOptionsPage(const IResOptionsPage& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
};
/////////////////////////////////////////////////////////////////////////////
// IPlugInOptionsPage wrapper class

class IPlugInOptionsPage : public COleDispatchDriver
{
public:
	IPlugInOptionsPage() {}		// Calls COleDispatchDriver default constructor
	IPlugInOptionsPage(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IPlugInOptionsPage(const IPlugInOptionsPage& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
};
/////////////////////////////////////////////////////////////////////////////
// ILanguageOptionsPage wrapper class

class ILanguageOptionsPage : public COleDispatchDriver
{
public:
	ILanguageOptionsPage() {}		// Calls COleDispatchDriver default constructor
	ILanguageOptionsPage(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	ILanguageOptionsPage(const ILanguageOptionsPage& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
};
/////////////////////////////////////////////////////////////////////////////
// IViewSettingsOptions wrapper class

class IViewSettingsOptions : public COleDispatchDriver
{
public:
	IViewSettingsOptions() {}		// Calls COleDispatchDriver default constructor
	IViewSettingsOptions(LPDISPATCH pDispatch) : COleDispatchDriver(pDispatch) {}
	IViewSettingsOptions(const IViewSettingsOptions& dispatchSrc) : COleDispatchDriver(dispatchSrc) {}

// Attributes
public:

// Operations
public:
};
